.. _administration-ui:

=================================
Overview of the Administration UI
=================================

The Administration UI provides configuration options, database management,
news updates and system information. This area is available to all users with
:ref:`staff status <staff-status>` and can be reached by clicking
:guilabel:`Admin` in your account navigation menu in the top-right of any
page.

The Administration UI is composed of four main areas:

* :ref:`Admin Dashboard <administrator-dashboard>`
* :ref:`Database <database-management>`
* :ref:`Extensions <extensions>`
* :ref:`Settings <settings>`
